// ======================================================================
//
// DebugPage.h
// jeff grills
//
// copyright 1997 origin systems inc
//
// ======================================================================

#ifndef DEBUG_PAGE_H
#define DEBUG_PAGE_H

#if USE_DEBUG_PAGE

// ======================================================================

class DebugPage
{
	friend class DebugPageManager;

public:

	enum 
	{
		WIDTH   = 80,
		HEIGHT  = 25
	};

private:

	int        id;
	int        width;
	int        height;
	int        cursorX;
	int        cursorY;
	char      *text;
	DebugPage *next;

private:

	// disable
	DebugPage(void);
	DebugPage(const DebugPage &);
	DebugPage &operator=(const DebugPage &);

private:

	DebugPage(int pageId, int pageWidth, int pageHeight);
	~DebugPage(void);

public:

	void clearScreen(void);
	void gotoXY(int x, int y);
	void whereXY(int *x, int *y) const;
	void printf(const char *fmt, ...);

	void display(void) const;
};

class DebugPageManager
{
	static DebugPage *firstPage;
	static DebugPage *currentPage;

public:

	static void install(void);
	static void remove(void);
	
	static void display(void);

	static DebugPage *createPage(int pageId, int width=DebugPage::WIDTH, int height=DebugPage::HEIGHT);
	static void       deletePage(DebugPage *page);
	static void       deletePage(int pageId);
	static DebugPage *findPage(int pageId);
	static int        findFreePage(void);

	static void nextOutputPage(void);
	static void previousOutputPage(void);
	static void selectOutputPage(int pageId);
	static void selectOutputPage(DebugPage *page);
};

// ======================================================================

inline void DebugPageManager::selectOutputPage(int pageId)
{
	selectOutputPage(findPage(pageId));
}

inline void DebugPageManager::selectOutputPage(DebugPage *page)
{
	currentPage=page;
}

inline void DebugPageManager::deletePage(int pageId)
{
	deletePage(findPage(pageId));
}

// ======================================================================

#endif
#endif
